@@ -27,7 +27,7 @@ from acryl.executor.execution.task import TaskError
 from acryl.executor.result.execution_result import Type
 from acryl.executor.context.executor_context import ExecutorContext
 from acryl.executor.context.execution_context import ExecutionContext
-from acryl.executor.common.config import ConfigModel
+from acryl.executor.common.config import ConfigModel, PermissiveConfigModel
 
 logger = logging.getLogger(__name__)
 
@@ -36,7 +36,7 @@ class SubProcessIngestionTaskConfig(ConfigModel):
     heartbeat_time_seconds: int = 2
     max_log_lines: int = SubProcessTaskUtil.MAX_LOG_LINES
 
-class SubProcessIngestionTaskArgs(ConfigModel):
+class SubProcessIngestionTaskArgs(PermissiveConfigModel):
     recipe: str
     version: str = "latest"
     debug_mode: str = "false" # Expected values are "true" or "false". 
@@ -79,6 +79,7 @@ class SubProcessIngestionTask(Task):
         command_script: str = "run_ingest.sh" # TODO: Make sure this is EXECUTABLE before running
 
         stdout_lines: deque[str] = deque(maxlen=self.config.max_log_lines)
+        full_log_file = open(f"{exec_out_dir}/ingestion_log.txt", "w")
 
         report_out_file = f"{exec_out_dir}/ingestion_report.json"
 
@@ -87,15 +88,33 @@ class SubProcessIngestionTask(Task):
             *[command_script, exec_id, datahub_version, plugins, self.tmp_dir, f"{exec_out_dir}/recipe.yml", report_out_file, debug_mode],
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.STDOUT,
+            limit=SubProcessTaskUtil.SUBPROCESS_BUFFER_SIZE,
         )
 
         # 4. Monitor and report progress.
         most_recent_log_ts: Optional[datetime] = None
 
         async def _read_output_lines() -> None:
+            create_new_line = True
             while True:
                 assert ingest_process.stdout
-                line_bytes = await ingest_process.stdout.readline()
+
+                # We can't use the readline method directly.
+                # When the readline method hits a LimitOverrunError, it will
+                # discard the line or possibly the entire buffer.
+                try:
+                    line_bytes = await ingest_process.stdout.readuntil(b'\n')
+                except asyncio.exceptions.IncompleteReadError as e:
+                    # This happens when we reach the end of the stream.
+                    line_bytes = e.partial
+                except asyncio.exceptions.LimitOverrunError as e:
+                    line_bytes = await ingest_process.stdout.read(SubProcessTaskUtil.MAX_BYTES_PER_LINE)
+                
+                # At this point, if line_bytes is empty, then we're at EOF.
+                # If it ends with a newline, then we successfully read a line.
+                # If it does not end with a newline, then we hit a LimitOverrunError
+                # and it contains a partial line.
+
                 if not line_bytes:
                     logger.info(f'Got EOF from subprocess exec_id={exec_id} - stopping log monitor')
                     break
@@ -104,9 +123,27 @@ class SubProcessIngestionTask(Task):
                 nonlocal most_recent_log_ts
                 most_recent_log_ts = datetime.now()
 
-                sys.stdout.write(line)
-                sys.stdout.flush()
-                stdout_lines.append(line)
+                full_log_file.write(line)
+
+                if create_new_line:
+                    stdout_lines.append("")
+                    sys.stdout.write(f'[{exec_id} logs] ')
+                create_new_line = line.endswith('\n')
+
+                current_line_length = len(stdout_lines[-1])
+                if current_line_length < SubProcessTaskUtil.MAX_BYTES_PER_LINE:
+                    allowed_length = SubProcessTaskUtil.MAX_BYTES_PER_LINE - current_line_length
+                    if len(line) > allowed_length:
+                        trunc_line = f"{line[:allowed_length]} [...truncated]\n"
+                    else:
+                        trunc_line = line
+
+                    stdout_lines[-1] += trunc_line
+                    sys.stdout.write(trunc_line)
+                    sys.stdout.flush()
+                else:
+                    # If we've already reached the max line length, then we simply ignore the rest of the line.
+                    pass
 
                 await asyncio.sleep(0)
         
@@ -131,8 +168,10 @@ class SubProcessIngestionTask(Task):
                             report = f'{report}\n\n{message}'
 
                     # TODO maybe use the normal report field here?
+                    logger.debug(f'Reporting in-progress for exec_id={exec_id}')
                     ctx.request.progress_callback(report)
 
+                full_log_file.flush()
                 await asyncio.sleep(0)
         
         async def _process_waiter() -> None:
@@ -146,6 +185,8 @@ class SubProcessIngestionTask(Task):
             ingest_process.terminate()
             raise
         finally:
+            full_log_file.close()
+
             if os.path.exists(report_out_file):
                 with open(report_out_file,'r') as structured_report_fp:
                     ctx.get_report().set_structured_report(structured_report_fp.read())
