@@ -31,10 +31,18 @@ class SubProcessTaskUtil:
 
     MAX_LOG_LINES = 2000
 
+    # The original value is 64kb (https://github.com/python/cpython/blob/7528e2c06c8baf809b56f406bcc50e8436c9647c/Lib/asyncio/streams.py#L23).
+    # We are increasing it to 1mb, which should improve performance.
+    SUBPROCESS_BUFFER_SIZE = 2 ** 20
+
+    # Since GMS has a 4mb limit on the size of a data packet, we want
+    # to truncate long lines.
+    MAX_BYTES_PER_LINE = 2 ** 12  # 4kb
+
     @staticmethod
     def _format_log_lines(lines: Sequence[str]) -> str: 
         text = "".join(lines)
-        if len(lines) > SubProcessTaskUtil.MAX_LOG_LINES:
+        if len(lines) >= SubProcessTaskUtil.MAX_LOG_LINES:
             text = f"[earlier logs truncated...]\n{text}"
 
         return text
