@@ -22,7 +22,7 @@ from acryl.executor.execution.task import Task
 from acryl.executor.execution.task import TaskError
 from acryl.executor.context.executor_context import ExecutorContext
 from acryl.executor.context.execution_context import ExecutionContext
-from acryl.executor.common.config import ConfigModel
+from acryl.executor.common.config import ConfigModel, PermissiveConfigModel
 from acryl.executor.execution.sub_process_task_common import SubProcessTaskUtil
 from typing import List
 
@@ -31,7 +31,7 @@ logger = logging.getLogger(__name__)
 class SubProcessTestConnectionTaskConfig(ConfigModel):
     tmp_dir: str = "/tmp/datahub/ingest"
 
-class SubProcessTestConnectionTaskArgs(ConfigModel):
+class SubProcessTestConnectionTaskArgs(PermissiveConfigModel):
     recipe: str
     version: str = "latest"
 
